@@ -11,14 +11,14 @@ class GStream(object):
     """
 
     _closed = None
-    read_file = None
-    write_file = None
+    rfile = None
+    wfile = None
     on_close_callback = None
 
     def __init__(self, sock):
         self.sock = sock
-        self.read_file = sock.makefile('rb')
-        self.write_file = sock.makefile('wb', 0)
+        self.rfile = sock.makefile('rb')
+        self.wfile = sock.makefile('wb', 0)
         self._closed = False
 
     def close(self, exc_info=False):
@@ -28,13 +28,13 @@ class GStream(object):
 
         self._closed = True
 
-        if self.read_file:
-            self.read_file.close()
-            self.read_file = None
+        if self.rfile:
+            safe_call(self.rfile.close)
+            self.rfile = None
 
-        if self.write_file:
-            self.write_file.close()
-            self.write_file = None
+        if self.wfile:
+            safe_call(self.wfile.close)
+            self.wfile = None
 
         if self.sock:
             safe_call(self.sock.close)
@@ -51,7 +51,7 @@ class GStream(object):
         接收消息
         """
 
-        data = self.read_file.readline()
+        data = self.rfile.readline()
         if not data:
             # 重复调用也没关系
             self.close()
@@ -67,8 +67,8 @@ class GStream(object):
         写数据
         """
 
-        if self.write_file:
-            self.write_file.write(data)
+        if self.wfile:
+            safe_call(self.wfile.write, data)
             safe_call(callback)
 
     def closed(self):
@@ -89,10 +89,10 @@ class GStream(object):
                     self.sock.family in (socket.AF_INET, socket.AF_INET6)):
             try:
                 self.sock.setsockopt(socket.IPPROTO_TCP,
-                                       socket.TCP_NODELAY, 1 if value else 0)
+                                     socket.TCP_NODELAY, 1 if value else 0)
             except socket.error as e:
                 # Sometimes setsockopt will fail if the socket is closed
                 # at the wrong time.  This can happen with HTTPServer
                 # resetting the value to false between requests.
                 if e.errno not in (errno.EINVAL, errno.ECONNRESET):
-                    raise
+                    raise
\ No newline at end of file
